summaryrefslogtreecommitdiff
path: root/make-boot-image.sh
diff options
context:
space:
mode:
Diffstat (limited to 'make-boot-image.sh')
-rwxr-xr-xmake-boot-image.sh6
1 files changed, 3 insertions, 3 deletions
diff --git a/make-boot-image.sh b/make-boot-image.sh
index 840cce7..943f10a 100755
--- a/make-boot-image.sh
+++ b/make-boot-image.sh
@@ -1,6 +1,6 @@
#!/bin/bash -xe
PS4='+ ($LINENO) ' # To ease debugging
-VERSION="1.2-emac-rc1"
+VERSION="1.2-emac-rc2"
# Config #
##########
@@ -148,7 +148,7 @@ then check_free_space $ROOT_MIN_AVAIL_MIO /
# Optionnally qemu to run the result for santity checking
[ "x$DEVEL_MODE" = "xy" ] && $ROOTCMD apt-get install qemu-system-x86
# Dependencies to put into the initrd
# util-linux : fdisk, sfdisk, lsblk, setterm
# net-tools : mii-tool
# ncurses-bin : tput
$ROOTCMD apt-get install dmidecode pciutils usbutils lshw sysstat iftop strace rsync \
@@ -378,7 +378,7 @@ then (
# Network tools
mkchroot "$WORKDIR/initrd" mii-tool ethtool
# Disk tools
- mkchroot "$WORKDIR/initrd" fdisk gdisk sfdisk sgdisk
+ mkchroot "$WORKDIR/initrd" blkdiscard fdisk gdisk sfdisk sgdisk
# Cloning tools
mkchroot "$WORKDIR/initrd" /usr/sbin/partclone* efibootmgr pigz scp rsync
# Some dyn-loaded libraries (ldd will not display them)
@@ -148,7 +148,7 @@ then check_free_space $ROOT_MIN_AVAIL_MIO /
[ "x$DEVEL_MODE" = "xy" ] && $ROOTCMD apt-get install qemu-system-x86
# Dependencies to put into the initrd
- # util-linux : fdisk, sfdisk, lsblk, setterm
+ # util-linux : blkdiscard, fdisk, sfdisk, lsblk, setterm
# net-tools : mii-tool
# ncurses-bin : tput